'\" t
.TH lib3270 3 "18 June 2002"
.SH "NAME"
lib3270 \-
\s-1IBM\s+1 host access library
.SH "SYNOPSIS"
#include "lib3270.h"
.br
cc ... -l3270
.SH "DESCRIPTION"
\fBlib3270\fP allows a C program to open
a telnet connection to an \s-1IBM\s+1
host, then allows the program to control the host login
session.
It is derived from
\fIx3270\fP(1),
an X-windows IBM 3270 emulator.
It implements RFCs 2355 (TN3270E), 1576 (TN3270) and 1646 (LU name selection),
and supports IND$FILE file transfer.
.SH "BASIC FUNCTIONS"
\fBlib3270\fP is controlled by several basic access functions:
.TP
int open_3270(unsigned long \fIflags\fP, const char **\fIoptions\fP, l3h_t *\fIhandle_ret\fP)
Initializes an instance of \fBlib3270\fP.
\fIflags\fP can include \s-1NON_BLOCKING\s+1, which causes certain functions
to operate in an asynchronous manner.
\fIoptions\fP is a \s-1NULL\s+1-terminated array of option strings (see
\s-1OPTIONS\s+1 below).
Returns a handle for use by other \fBlib3270\fP functions.
.TP
int close_3270(lib327h_t \fIh\fP)
Terminates an instance of \fBlib3270\fP.
.TP
int poll_3270(l3h_t \fIh\fP)
Perform any pending I/O operations (without blocking) and return the status
of any pending function.
.TP
int wait_3270(l3h_t \fIh\fP)
Wait for any pending function to complete and return its status.
.TP
const char *result_3270(l3h_t \fIh\fP, int *\fIrcode\fP)
Return the result of the last 3270 function.  Its return code is returned in
\fIrcode\fP.
If the last 3270 function succeeded, the result is whatever output it produced.
If it failed, the result is an error message.
.TP
int selectvals_3270(l3h_t \fIh\fP, int *\fInfds\fP, fd_set *\fIreadfds\fP, fd_set *\fIwritefds\fP, fd_set *\fIexceptfds\fP, struct timeval **\fItimeout\fP, struct timeval *\fItimebuf\fP)
Used in non-blocking mode to return information about pending I/O and timeout
operations.
All of the parameters can already contain values and will be correctly
modified; otherwise they should be initialized to zero.
File descriptors for \fBlib3270\fP's pending I/O operations
are OR'ed into \fIreadfs\fP, \fIwritefds\fP and \fIexceptfds\fP;
\fInfds\fP is modified if one of those file descriptors equals or exceeds
its value.
If there is a \fBlib3270\fP timeout pending and \fItimeout\fP already points to a non-\s-1NULL\s+1
value which is greater than what \fBlib3270\fP requires, that value is
updated.
If there is a \fBlib3270\fP timeout pending and \fItimeout\fP is \s-1NULL\s+1,
then it will be set to point to \fItimebuf\fP, and \fItimebuf\fP will be set
to the correct value.
.IP
Returns 1 if there are events pending, 0 if not, <0 for an error.
.LP
The return codes from the above functions, and from other 3270 functions which
return integers, are as follows.
Note that all of the failure values are less than zero.
.TP
L_OK (0)
Success.
.TP
L_FAIL
Function failed.
.TP
L_BLOCKED
\fBlib3270\fP is operating in non-blocking mode, and the function has not
yet completed.
.TP
L_NESTED
A function is already pending, and a new function was attempted.
.TP
L_BADHANDLE
The handle (l3h_t) parameter is invalid.
.LP
3270 functions which return character strings cannot block, so they return a
non-\s-1NULL\s+1 string for success, and a \s-1NULL\s+1 string for failure.
.SH "OPTIONS"
\fBlib3270\fP's initialization function understands
the following options:
.TP
\fB\-charset\fP \fIname\fP
Specifies an \s-1EBCDIC\s+1 host character set.
See \s-1CHARACTER SETS\s+1 below.
.TP
\fB\-clear\fP \fItoggle\fP
Sets the initial value of \fItoggle\fP to \fBfalse\fP.
The list of toggle names is under \s-1TOGGLES\s+1
below.
.TP
\fB\-model\fP \fIname\fP
The model of 3270 display to be emulated.
The model name is in two parts, either of which may be omitted:
.IP
The first part is the
\fBbase model\fP,
which is either \fB3278\fP or \fB3279\fP.
\fB3278\fP specifies a monochrome 3270 display;
\fB3279\fP specifies a color 3270 display.
.IP
The second part is the
\fBmodel number\fP,
which specifies the number of rows and columns.
Model 4 is the default.
.PP
.TS
center;
c c c .
T{
.na
.nh
Model Number
T}	T{
.na
.nh
Columns
T}	T{
.na
.nh
Rows
T}
_
T{
.na
.nh
2
T}	T{
.na
.nh
80
T}	T{
.na
.nh
24
T}
T{
.na
.nh
3
T}	T{
.na
.nh
80
T}	T{
.na
.nh
30
T}
T{
.na
.nh
4
T}	T{
.na
.nh
80
T}	T{
.na
.nh
43
T}
T{
.na
.nh
5
T}	T{
.na
.nh
132
T}	T{
.na
.nh
27
T}
.TE
.IP
Note: Technically, there is no such 3270 display as a 3279-4 or 3279-5, but
most hosts seem to work with them anyway.
.IP
The default model
is \fB3278\-4\fP.
.TP
\fB\-mono\fP
Forces 3278 emulation.
.TP
\fB\-oversize\fP \fIcols\fP\fBx\fP\fIrows\fP
Makes the screen larger than the default for the chosen model number.
This option has effect only in combination with extended data stream support
(controlled by the "lib3270.extended" resource), and only if the host
supports the Query Reply structured field.
The number of columns multiplied by the number of rows must not exceed
16383 (3fff hex), the limit of 14-bit 3270 buffer addressing.
.TP
\fB\-port\fP \fIn\fP
Specifies a different \s-1TCP\s+1 port to connect to.
\fIn\fP can be a name from \fB/etc/services\fP like \fBtelnet\fP, or a
number.
This option changes the default port number used for all connections.
(The positional parameter affects only the initial connection.)
.TP
\fB\-set\fP \fItoggle\fP
Sets the initial value of \fItoggle\fP to \fBtrue\fP.
The list of toggle names is under \s-1TOGGLES\s+1
below.
.TP
\fB\-tn\fP \fIname\fP
Specifies the terminal name to be transmitted over the telnet connection.
The default name is
\fBIBM\-\fP\fImodel_name\fP\fB\-E\fP,
for example,
\fBIBM\-3278\-4\-E\fP.
.IP
Some hosts are confused by the \fB\-E\fP
suffix on the terminal name, and will ignore the extra screen area on
models 3, 4 and 5.
Prepending an \fB:s\fP on the hostname, or setting the "lib3270.extended"
resource to "false", removes the \fB\-E\fP
from the terminal name when connecting to such hosts.
.IP
The name can also be specified with the "lib3270.termName" resource.
.TP
\fB\-trace\fP
Turns on data stream and event tracing at startup.
The default trace file name is
\fB/tmp/x3trc.\fP\fIprocess_id\fP.
.TP
\fB\-tracefile\fP \fIfile\fP
Specifies a file to save data stream and event traces into, overriding the
default of
\fB/tmp/x3trc.\fP\fIprocess_id\fP.
.TP
\fB\-tracefilesize\fP \fIsize\fP
Places a limit on the size of a trace file.
If this option is not specified, or is specified as \fB0\fP or \fBnone\fP,
the trace file will be unlimited.
If specified, the trace file cannot already exist, and the (silently enforced)
minimum size is 64 Kbytes.
The value of \fIsize\fP can have a \fBK\fP or \fBM\fP suffix, indicating
kilobytes or megabytes respectively.
.TP
\fB\-xrm\fP "lib3270.\fIresource\fP: \fIvalue\fP"
Sets the value of the named \fIresource\fP to \fIvalue\fP.
Resources control less common \fBlib3270\fP
options, and are defined under \s-1RESOURCES\s+1 below.
.SH "HOSTNAME SYNTAX"
The full syntax for \fIhost\fP is:
.RS
[\fIprefix\fP:]...[\fILUname\fP@]\fIhostname\fP[:\fIport\fP]
.RE
.LP
Prepending a \fBp:\fP onto \fIhostname\fP causes the connection to go
through the \fItelnet-passthru\fP service rather than directly to the host.
See \s-1PASSTHRU\s+1 below.
.LP
Prepending an \fBs:\fP onto \fIhostname\fP removes the "extended data
stream" option reported to the host.
See \fB\-tn\fP below for further information.
.LP
Prepending an \fBn:\fP onto \fIhostname\fP
turns off TN3270E support for the session.
.LP
A specific LU name to use may be specified by prepending it to the
\fIhostname\fP with an `\fB@\fP'.
Multiple LU names to try can be separated by commas.
An empty LU can be placed in the list with an extra comma.
.LP
On systems that support the \fIforkpty\fP library call, the
\fIhostname\fP may be replaced with \fB\-e\fP and a command string.
This will cause \fBlib3270\fP to connect to a local child process, such as
a shell.
.LP
The port to connect to defaults to
\fBtelnet\fP.
This can be overridden with the \fB\-port\fP option, or by appending
a \fIport\fP to the \fIhostname\fP with a colon
`\fB:\fP'.
.SH "CHARACTER SETS"
The \fB\-charset\fP
option or the "lib3270.charset" resource controls the \s-1EBCDIC\s+1
host character set used by \fBlib3270\fP.
Available sets include:
.PP
.TS
center;
l l l
lfB l l.
T{
.na
.nh
Charset Name
T}	T{
.na
.nh
Code Page
T}	T{
.na
.nh
Display Character Sets
T}
_
T{
.na
.nh
apl
T}	T{
.na
.nh
37
T}	T{
.na
.nh
3270cg-1a
T}
T{
.na
.nh
belgian
T}	T{
.na
.nh
500
T}	T{
.na
.nh
3270cg-1a 3270-cg1 iso8859-1
T}
T{
.na
.nh
bracket
T}	T{
.na
.nh
37
T}	T{
.na
.nh
3270cg-1a 3270-cg1 iso8859-1
T}
T{
.na
.nh
brazilian
T}	T{
.na
.nh
275
T}	T{
.na
.nh
3270cg-1a 3270-cg1 iso8859-1
T}
T{
.na
.nh
finnish
T}	T{
.na
.nh
278
T}	T{
.na
.nh
3270cg-1a 3270-cg1 iso8859-1
T}
T{
.na
.nh
french
T}	T{
.na
.nh
297
T}	T{
.na
.nh
3270cg-1a 3270-cg1 iso8859-1
T}
T{
.na
.nh
german
T}	T{
.na
.nh
273
T}	T{
.na
.nh
3270cg-1a 3270-cg1 iso8859-1
T}
T{
.na
.nh
icelandic
T}	T{
.na
.nh
871
T}	T{
.na
.nh
3270cg-1a 3270-cg1 iso8859-1
T}
T{
.na
.nh
iso-hebrew
T}	T{
.na
.nh
424
T}	T{
.na
.nh
iso8859-8
T}
T{
.na
.nh
iso-turkish
T}	T{
.na
.nh
1026
T}	T{
.na
.nh
iso8859-9
T}
T{
.na
.nh
italian
T}	T{
.na
.nh
280
T}	T{
.na
.nh
3270cg-1a 3270-cg1 iso8859-1
T}
T{
.na
.nh
norwegian
T}	T{
.na
.nh
277
T}	T{
.na
.nh
3270cg-1a 3270-cg1 iso8859-1
T}
T{
.na
.nh
russian
T}	T{
.na
.nh
880
T}	T{
.na
.nh
koi8-r
T}
T{
.na
.nh
solvenian
T}	T{
.na
.nh
870
T}	T{
.na
.nh
iso8859-2
T}
T{
.na
.nh
thai
T}	T{
.na
.nh
838
T}	T{
.na
.nh
iso8859-11 tis620.2529-0
T}
T{
.na
.nh
uk
T}	T{
.na
.nh
285
T}	T{
.na
.nh
3270cg-1a 3270-cg1 iso8859-1
T}
T{
.na
.nh
us-intl
T}	T{
.na
.nh
37
T}	T{
.na
.nh
3270cg-1a 3270-cg1 iso8859-1
T}
.TE
.PP
The default character set is
\fBbracket\fP,
which is useful for common \s-1IBM\s+1 hosts which use \s-1EBCDIC\s+1
codes 0xAD and 0xBD for the `[' and `]' characters,
respectively.
.SH "NVT (ANSI) MODE"
Some hosts use an \s-1ASCII\s+1 front-end to do initial login negotiation,
then later switch to 3270 mode.
\fBlib3270\fP will emulate an \s-1ANSI\s+1 X.64 terminal until the host
places it in 3270 mode (telnet \s-1BINARY\s+1 and \s-1SEND EOR\s+1 modes, or
\s-1TN3270E\s+1 mode negotiation).
.PP
If the host later negotiates to stop functioning in 3270 mode,
\fBlib3270\fP will return to \s-1ANSI\s+1 emulation.
.PP
In \s-1NVT\s+1 mode, \fBlib3270\fP
supports both character-at-a-time mode and line mode operation.
You may select the mode with a menu option.
When in line mode, the special characters and operational characteristics are
defined by resources:
.PP
.TS
center;
l c c.
T{
.na
.nh
Mode/Character
T}	T{
.na
.nh
Resource
T}	T{
.na
.nh
Default
T}
_
T{
.na
.nh
Translate CR to NL
T}	T{
.na
.nh
lib3270.icrnl
T}	T{
.na
.nh
true
T}
T{
.na
.nh
Translate NL to CR
T}	T{
.na
.nh
lib3270.inlcr
T}	T{
.na
.nh
false
T}
T{
.na
.nh
Erase previous character
T}	T{
.na
.nh
lib3270.erase
T}	T{
.na
.nh
^?
T}
T{
.na
.nh
Erase entire line
T}	T{
.na
.nh
lib3270.kill
T}	T{
.na
.nh
^U
T}
T{
.na
.nh
Erase previous word
T}	T{
.na
.nh
lib3270.werase
T}	T{
.na
.nh
^W
T}
T{
.na
.nh
Redisplay line
T}	T{
.na
.nh
lib3270.rprnt
T}	T{
.na
.nh
^R
T}
T{
.na
.nh
Ignore special meaning of next character
T}	T{
.na
.nh
lib3270.lnext
T}	T{
.na
.nh
^V
T}
T{
.na
.nh
Interrupt
T}	T{
.na
.nh
lib3270.intr
T}	T{
.na
.nh
^C
T}
T{
.na
.nh
Quit
T}	T{
.na
.nh
lib3270.quit
T}	T{
.na
.nh
^\e
T}
T{
.na
.nh
End of file
T}	T{
.na
.nh
lib3270.eof
T}	T{
.na
.nh
^D
T}
.TE
.SH "TOGGLES"
\fBlib3270\fP has a number of configurable modes which may be selected by
the \fB\-set\fP and \fB\-clear\fP options.
.TP
\fBmonoCase\fP
If set, \fBlib3270\fP operates in uppercase-only mode.
.TP
\fBblankFill\fP
If set, \fBlib3270\fP behaves in some un-3270-like ways.
First, when a character is typed into a field, all nulls in the field to the
left of that character are changed to blanks.
This eliminates a common 3270 data-entry surprise.
Second, in insert mode, trailing blanks in a field are treated like nulls,
eliminating the annoying `lock-up' that often occurs when inserting
into an field with (apparent) space at the end.
.TP
\fBlineWrap\fP
If set, the \s-1ANSI\s+1 terminal emulator automatically assumes
a \s-1NEWLINE\s+1 character when it reaches the end of a line.
.LP
The names of the toggles for use with the \fB\-set\fP
and \fB\-clear\fP
options are as follows:
.LP
.TS
center;
l l .
T{
.na
.nh
Option
T}	T{
.na
.nh
Name
T}
_
T{
.na
.nh
Monocase
T}	T{
.na
.nh
monoCase
T}
T{
.na
.nh
Blank Fill
T}	T{
.na
.nh
blankFill
T}
T{
.na
.nh
Track Cursor
T}	T{
.na
.nh
cursorPos
T}
T{
.na
.nh
Trace Data Stream
T}	T{
.na
.nh
dsTrace
T}
T{
.na
.nh
Trace Events
T}	T{
.na
.nh
eventTrace
T}
T{
.na
.nh
Save Screen(s) in File
T}	T{
.na
.nh
screenTrace
T}
T{
.na
.nh
Wraparound
T}	T{
.na
.nh
lineWrap
T}
.TE
.LP
These names are also used as the first parameter to the \fBToggle\fP
function.
.SH "FUNCTIONS"
\fBlib3270\fP supports the following functions.
Functions which begin with \fBs\fP are synchronous (they can never return
\s-1L_BLOCKED\s+1 in non-blocking mode).
Functions which begin with \fBa\fP are asynchronous (in non-blocking mode,
they may return \s-1L_BLOCKED\s+1).
.LP
Return values are kept in a 10-element ring, so that up to
ten \fBlib3270\fP library calls may be used in the same expression.
.LP
Functions which take a \fItimeout\fP parameter specify the timeout in
seconds.  A value of 0 is used to wait indefinitely.
.PP
.TS
center; lw(3i) lw(3i).
T{
.na
.nh
.in +2
.ti -2
const char *sAsciiAll(l3h_t \fIh\fP)
T}	T{
.na
.nh
return entire screen contents in \s-1ASCII\s+1
T}
T{
.na
.nh
.in +2
.ti -2
const char *sAsciiFromCursor(l3h_t \fIh\fP, int \fIlength\fP)
T}	T{
.na
.nh
return screen contents at cursor in \s-1ASCII\s+1
T}
T{
.na
.nh
.in +2
.ti -2
const char *sAsciiLine(l3h_t \fIh\fP, int \fIrow\fP, int \fIcol\fP, int \fIlength\fP)
T}	T{
.na
.nh
return screen contents in \s-1ASCII\s+1
T}
T{
.na
.nh
.in +2
.ti -2
const char *sAsciiBlock(l3h_t \fIh\fP, int \fIrow\fP, int \fIcol\fP, int \fIrows\fP, int \fIcols\fP)
T}	T{
.na
.nh
return screen region in \s-1ASCII\s+1
T}
T{
.na
.nh
.in +2
.ti -2
const char *int AsciiField(l3h_t \fIh\fP)
T}	T{
.na
.nh
return current field in \s-1ASCII\s+1
T}
T{
.na
.nh
.in +2
.ti -2
int sXX_BLOCK()Attn(l3h_t \fIh\fP)
T}	T{
.na
.nh
attention key
T}
T{
.na
.nh
.in +2
.ti -2
int sBackSpace(l3h_t \fIh\fP)
T}	T{
.na
.nh
move cursor left (or send \s-1ASCII BS\s+1)
T}
T{
.na
.nh
.in +2
.ti -2
int sBackTab(l3h_t \fIh\fP)
T}	T{
.na
.nh
tab to start of previous input field
T}
T{
.na
.nh
.in +2
.ti -2
int aXX_BLOCK()Clear(l3h_t \fIh\fP)
T}	T{
.na
.nh
clear screen
T}
T{
.na
.nh
.in +2
.ti -2
int sCols(l3h_t \fIh\fP)
T}	T{
.na
.nh
report screen size
T}
T{
.na
.nh
.in +2
.ti -2
int aXX_BLOCK()Connect(l3h_t \fIh\fP, const char *\fIhost\fP)
T}	T{
.na
.nh
connect to \fIhost\fP
T}
T{
.na
.nh
.in +2
.ti -2
int aXX_BLOCK()CursorSelect(l3h_t \fIh\fP)
T}	T{
.na
.nh
Cursor Select \s-1AID\s+1
T}
T{
.na
.nh
.in +2
.ti -2
int sDelete(l3h_t \fIh\fP)
T}	T{
.na
.nh
delete character under cursor (or send \s-1ASCII DEL\s+1)
T}
T{
.na
.nh
.in +2
.ti -2
int sDeleteField(l3h_t \fIh\fP)
T}	T{
.na
.nh
delete the entire field
T}
T{
.na
.nh
.in +2
.ti -2
int sDeleteWord(l3h_t \fIh\fP)
T}	T{
.na
.nh
delete the current or previous word
T}
T{
.na
.nh
.in +2
.ti -2
int sXX_BLOCK()Disconnect(l3h_t \fIh\fP)
T}	T{
.na
.nh
disconnect from host
T}
T{
.na
.nh
.in +2
.ti -2
int sDown(l3h_t \fIh\fP)
T}	T{
.na
.nh
move cursor down
T}
T{
.na
.nh
.in +2
.ti -2
int sDup(l3h_t \fIh\fP)
T}	T{
.na
.nh
duplicate field
T}
T{
.na
.nh
.in +2
.ti -2
const char *sEbcdicAll(l3h_t \fIh\fP)
T}	T{
.na
.nh
return entire screen contents in \s-1EBCDIC\s+1
T}
T{
.na
.nh
.in +2
.ti -2
const char *sEbcdicFromCursor(l3h_t \fIh\fP, int \fIlength\fP)
T}	T{
.na
.nh
return screen contents at cursor in \s-1EBCDIC\s+1
T}
T{
.na
.nh
.in +2
.ti -2
const char *sEbcdicLine(l3h_t \fIh\fP, int \fIrow\fP, int \fIcol\fP, int \fIlength\fP)
T}	T{
.na
.nh
return screen contents in \s-1EBCDIC\s+1
T}
T{
.na
.nh
.in +2
.ti -2
const char *sEbcdicBlock(l3h_t \fIh\fP, int \fIrow\fP, int \fIcol\fP, int \fIrows\fP, int \fIcols\fP)
T}	T{
.na
.nh
return screen region in \s-1EBCDIC\s+1
T}
T{
.na
.nh
.in +2
.ti -2
const char *int EbcdicField(l3h_t \fIh\fP)
T}	T{
.na
.nh
return current field in \s-1EBCDIC\s+1
T}
T{
.na
.nh
.in +2
.ti -2
int aXX_BLOCK()Enter(l3h_t \fIh\fP)
T}	T{
.na
.nh
Enter \s-1AID\s+1 (or send \s-1ASCII CR\s+1)
T}
T{
.na
.nh
.in +2
.ti -2
int sErase(l3h_t \fIh\fP)
T}	T{
.na
.nh
erase previous character (or send \s-1ASCII BS\s+1)
T}
T{
.na
.nh
.in +2
.ti -2
int sEraseEOF(l3h_t \fIh\fP)
T}	T{
.na
.nh
erase to end of current field
T}
T{
.na
.nh
.in +2
.ti -2
int sEraseInput(l3h_t \fIh\fP)
T}	T{
.na
.nh
erase all input fields
T}
T{
.na
.nh
.in +2
.ti -2
int sFieldEnd(l3h_t \fIh\fP)
T}	T{
.na
.nh
move cursor to end of field
T}
T{
.na
.nh
.in +2
.ti -2
int sFieldExit(l3h_t \fIh\fP)
T}	T{
.na
.nh
clear to end of field and skip to next (5250 emulation)
T}
T{
.na
.nh
.in +2
.ti -2
int sFieldMark(l3h_t \fIh\fP)
T}	T{
.na
.nh
mark field
T}
T{
.na
.nh
.in +2
.ti -2
int aHexString(l3h_t \fIh\fP, const char *\fIhex_digits\fP)
T}	T{
.na
.nh
insert control-character string
T}
T{
.na
.nh
.in +2
.ti -2
int sHome(l3h_t \fIh\fP)
T}	T{
.na
.nh
move cursor to first input field
T}
T{
.na
.nh
.in +2
.ti -2
int sInsert(l3h_t \fIh\fP)
T}	T{
.na
.nh
set insert mode
T}
T{
.na
.nh
.in +2
.ti -2
int sXX_BLOCK()Interrupt(l3h_t \fIh\fP)
T}	T{
.na
.nh
send \s-1TELNET IP\s+1 to host
T}
T{
.na
.nh
.in +2
.ti -2
int aKey(l3h_t \fIh\fP, const char *\fIkeysym\fP)
T}	T{
.na
.nh
insert key \fIkeysym\fP
T}
T{
.na
.nh
.in +2
.ti -2
int sLeft(l3h_t \fIh\fP)
T}	T{
.na
.nh
move cursor left
T}
T{
.na
.nh
.in +2
.ti -2
int sLeft2(l3h_t \fIh\fP)
T}	T{
.na
.nh
move cursor left 2 positions
T}
T{
.na
.nh
.in +2
.ti -2
int sMonoCase(l3h_t \fIh\fP)
T}	T{
.na
.nh
toggle uppercase-only mode
T}
T{
.na
.nh
.in +2
.ti -2
int sMoveCursor(l3h_t \fIh\fP, int \fIrow\fP, int \fIcol\fP)
T}	T{
.na
.nh
move cursor to (\fIrow\fP,\fIcol\fP)
T}
T{
.na
.nh
.in +2
.ti -2
int sNewline(l3h_t \fIh\fP)
T}	T{
.na
.nh
move cursor to first field on next line (or send \s-1ASCII LF\s+1)
T}
T{
.na
.nh
.in +2
.ti -2
int sNextWord(l3h_t \fIh\fP)
T}	T{
.na
.nh
move cursor to next word
T}
T{
.na
.nh
.in +2
.ti -2
int aXX_BLOCK()PA(l3h_t \fIh\fP, int \fIn\fP)
T}	T{
.na
.nh
Program Attention \s-1AID\s+1 (\fIn\fP from 1 to 3)
T}
T{
.na
.nh
.in +2
.ti -2
int aXX_BLOCK()PF(l3h_t \fIh\fP, \fIint n\fP)
T}	T{
.na
.nh
Program Function \s-1AID\s+1 (\fIn\fP from 1 to 24)
T}
T{
.na
.nh
.in +2
.ti -2
int sPreviousWord(l3h_t \fIh\fP)
T}	T{
.na
.nh
move cursor to previous word
T}
T{
.na
.nh
.in +2
.ti -2
int sRedraw(l3h_t \fIh\fP)
T}	T{
.na
.nh
redraw window
T}
T{
.na
.nh
.in +2
.ti -2
int sReset(l3h_t \fIh\fP)
T}	T{
.na
.nh
reset locked keyboard
T}
T{
.na
.nh
.in +2
.ti -2
int sRight(l3h_t \fIh\fP)
T}	T{
.na
.nh
move cursor right
T}
T{
.na
.nh
.in +2
.ti -2
int sRight2(l3h_t \fIh\fP)
T}	T{
.na
.nh
move cursor right 2 positions
T}
T{
.na
.nh
.in +2
.ti -2
int sRows(l3h_t \fIh\fP)
T}	T{
.na
.nh
report screen size
T}
T{
.na
.nh
.in +2
.ti -2
const char *sSnapAscii...
T}	T{
.na
.nh
report saved screen data (see \fBsAscii\fP)
T}
T{
.na
.nh
.in +2
.ti -2
int sSnapCols(l3h_t \fIh\fP)
T}	T{
.na
.nh
report saved screen size
T}
T{
.na
.nh
.in +2
.ti -2
const char *sSnapEbcdic...
T}	T{
.na
.nh
report saved screen data (see \fBsEbcdic\fP)
T}
T{
.na
.nh
.in +2
.ti -2
int sSnapRows(l3h_t \fIh\fP)
T}	T{
.na
.nh
report saved screen size
T}
T{
.na
.nh
.in +2
.ti -2
int sSnapSave(l3h_t \fIh\fP)
T}	T{
.na
.nh
save screen image
T}
T{
.na
.nh
.in +2
.ti -2
const char *sSnapStatus(l3h_t \fIh\fP)
T}	T{
.na
.nh
report saved connection status
T}
T{
.na
.nh
.in +2
.ti -2
int aXX_BLOCK()SnapWaitOuput(int \fItimeout\fP)
T}	T{
.na
.nh
wait for host output and save screen image
T}
T{
.na
.nh
.in +2
.ti -2
const char *sStatus(l3h_t \fIh\fP)
T}	T{
.na
.nh
report connection status
T}
T{
.na
.nh
.in +2
.ti -2
int aXX_BLOCK()String(l3h_t \fIh\fP, const char *\fIstring\fP)
T}	T{
.na
.nh
insert string (simple macro facility)
T}
T{
.na
.nh
.in +2
.ti -2
int aXX_BLOCK()SysReq(l3h_t \fIh\fP)
T}	T{
.na
.nh
System Request \s-1AID\s+1
T}
T{
.na
.nh
.in +2
.ti -2
int sTab(l3h_t \fIh\fP)
T}	T{
.na
.nh
move cursor to next input field
T}
T{
.na
.nh
.in +2
.ti -2
int sToggle(l3h_t \fIh\fP, \fIoption\fP[,\fIset|clear\fP])
T}	T{
.na
.nh
toggle an option
T}
T{
.na
.nh
.in +2
.ti -2
int sToggleInsert(l3h_t \fIh\fP)
T}	T{
.na
.nh
toggle insert mode
T}
T{
.na
.nh
.in +2
.ti -2
int sToggleReverse(l3h_t \fIh\fP)
T}	T{
.na
.nh
toggle reverse-input mode
T}
T{
.na
.nh
.in +2
.ti -2
int aXX_BLOCK()Transfer(l3h_t \fIh\fP, int \fIargc\fP, const char *\fIargv\fP[])
T}	T{
.na
.nh
file transfer
T}
T{
.na
.nh
.in +2
.ti -2
int sUp(l3h_t \fIh\fP)
T}	T{
.na
.nh
move cursor up
T}
T{
.na
.nh
.in +2
.ti -2
*int aWait3270mode(int \fItimeout\fP)
T}	T{
.na
.nh
wait for 3270 mode
T}
T{
.na
.nh
.in +2
.ti -2
*int aWaitDisconnect(int \fItimeout\fP)
T}	T{
.na
.nh
wait for host to disconnect
T}
T{
.na
.nh
.in +2
.ti -2
*int aWaitInputField(int \fItimeout\fP)
T}	T{
.na
.nh
wait for valid input field
T}
T{
.na
.nh
.in +2
.ti -2
*int aWaitNVTMode(int \fItimeout\fP)
T}	T{
.na
.nh
wait for NVT mode
T}
T{
.na
.nh
.in +2
.ti -2
*int aWaitOutput(int \fItimeout\fP)
T}	T{
.na
.nh
wait for more host output
T}
.TE
.SH "FILE TRANSFER"
The \fBaTransfer\fP function implements \fBIND$FILE\fP file transfer.
This function requires that the \fBIND$FILE\fP
program be installed on the \s-1IBM\s+1 host, and that the 3270 cursor
be located in a field that will accept a \s-1TSO\s+1 or \s-1VM/CMS\s+1 command.
.LP
Because of the complexity and number of options for file transfer, the
parameters to the \fBaTransfer\fP function take the unique form
of \fIoption\fP=\fIvalue\fP, and can appear in any order.
The options are:
.LP
.TS
l c l l.
T{
.na
.nh
Option
T}	T{
.na
.nh
Required?
T}	T{
.na
.nh
Default
T}	T{
.na
.nh
Other Values
T}
_
T{
.na
.nh
Direction
T}	T{
.na
.nh
No
T}	T{
.na
.nh
send
T}	T{
.na
.nh
receive
T}
T{
.na
.nh
HostFile
T}	T{
.na
.nh
Yes
T}	T{
.na
.nh
\ 
T}	T{
.na
.nh
\ 
T}
T{
.na
.nh
LocalFile
T}	T{
.na
.nh
Yes
T}	T{
.na
.nh
\ 
T}	T{
.na
.nh
\ 
T}
T{
.na
.nh
Host
T}	T{
.na
.nh
No
T}	T{
.na
.nh
tso
T}	T{
.na
.nh
vm
T}
T{
.na
.nh
Mode
T}	T{
.na
.nh
No
T}	T{
.na
.nh
ascii
T}	T{
.na
.nh
binary
T}
T{
.na
.nh
Cr
T}	T{
.na
.nh
No
T}	T{
.na
.nh
remove
T}	T{
.na
.nh
add, keep
T}
T{
.na
.nh
Exist
T}	T{
.na
.nh
No
T}	T{
.na
.nh
keep
T}	T{
.na
.nh
replace, append
T}
T{
.na
.nh
Recfm
T}	T{
.na
.nh
No
T}	T{
.na
.nh
\ 
T}	T{
.na
.nh
fixed, variable, undefined
T}
T{
.na
.nh
Lrecl
T}	T{
.na
.nh
No
T}	T{
.na
.nh
\ 
T}	T{
.na
.nh
\ 
T}
T{
.na
.nh
Blksize
T}	T{
.na
.nh
No
T}	T{
.na
.nh
\ 
T}	T{
.na
.nh
\ 
T}
T{
.na
.nh
Allocation
T}	T{
.na
.nh
No
T}	T{
.na
.nh
\ 
T}	T{
.na
.nh
tracks, cylinders, avblock
T}
T{
.na
.nh
PrimarySpace
T}	T{
.na
.nh
No
T}	T{
.na
.nh
\ 
T}	T{
.na
.nh
\ 
T}
T{
.na
.nh
SecondarySpace
T}	T{
.na
.nh
No
T}	T{
.na
.nh
\ 
T}	T{
.na
.nh
\ 
T}
.TE
.LP
The option details are as follows.
.TP
\fBDirection\fP
\fBsend\fP (the default) to send a file to the host,
\fBreceive\fP to receive a file from the host.
.TP
\fBHostFile\fP
The name of the file on the host.
.TP
\fBLocalFile\fP
The name of the file on the local workstation.
.TP
\fBHost\fP
The type of host (which dictates the form of the \fBIND$FILE\fP command):
\fBtso\fP (the default) or \fBvm\fP.
.TP
\fBMode\fP
Use \fBascii\fP (the default) for a text file, which will be translated
between \s-1EBCDIC\s+1 and \s-1ASCII\s+1 as necessary.
Use \fBbinary\fP for non-text files.
.TP
\fBCr\fP
Controls how \fBNewline\fP characters are handled when transferring
\fBMode=ascii\fP files.
\fBremove\fP (the default) strips \fBNewline\fP characters in local files
before transferring them to the host.
\fBadd\fP adds \fBNewline\fP characters to each host file record before
transferring it to the local workstation.
\fBkeep\fP preserves \fBNewline\fP characters when transferring a local file
to the host.
.TP
\fBExist\fP
Controls what happens when the destination file already exists.
\fBkeep\fP (the default) preserves the file, causing the
\fBaTransfer\fP function to fail.
\fBreplace\fP overwrites the destination file with the source file.
\fBappend\fP appends the source file to the destination file.
.TP
\fBRecfm\fP
Controls the record format of files created on the host.
\fBfixed\fP creates a file with fixed-length records.
\fBvariable\fP creates a file with variable-length records.
\fBundefined\fP creates a file with undefined-length records (\s-1TSO\s+1 hosts only).
The \fBLrecl\fP option controls the record length or maximum record length for
\fBRecfm=fixed\fP and \fBRecfm=variable\fP files, respectively.
.TP
\fBLrecl\fP
Specifies the record length (or maximum record length) for files created on
the host.
.TP
\fBBlksize\fP
Specifies the block size for files created on the host.  (\s-1TSO\s+1 hosts only.)
.TP
\fBAllocation\fP
Specifies the units for the \s-1TSO\s+1 host \fBPrimarySpace\fP and
\fBSecondarySpace\fP options: \fBtracks\fP, \fBcylinders\fP or
\fBavblock\fP.
.TP
\fBPrimarySpace\fP
Primary allocation for a file created on a \s-1TSO\s+1 host.
The units are given by the \fBAllocation\fP option.
.TP
\fBSecondarySpace\fP
Secondary allocation for a file created on a \s-1TSO\s+1 host.
The units are given by the \fBAllocation\fP option.
.SH "SCRIPTS"
.TP
\fBThe aString Function\fP
The simplest method for
scripting is provided via the \fBaString\fP
function.
The arguments to \fBaString\fP are one or more double-quoted strings which are
inserted directly as if typed.
The C backslash conventions are honored as follows.
(Entries marked * mean that after sending the \s-1AID\s+1 code to the host,
\fBlib3270\fP will wait for the host to unlock the keyboard before further
processing the string.)
.TS
l l.
T{
.na
.nh
\eb
T}	T{
.na
.nh
Left
T}
T{
.na
.nh
\ef
T}	T{
.na
.nh
Clear*
T}
T{
.na
.nh
\en
T}	T{
.na
.nh
Enter*
T}
T{
.na
.nh
\epa\fIn\fP
T}	T{
.na
.nh
PA(\fIn\fP)*
T}
T{
.na
.nh
\epf\fInn\fP
T}	T{
.na
.nh
PF(\fInn\fP)*
T}
T{
.na
.nh
\er
T}	T{
.na
.nh
Newline
T}
T{
.na
.nh
\et
T}	T{
.na
.nh
Tab
T}
T{
.na
.nh
\eT
T}	T{
.na
.nh
BackTab
T}
.TE
.IP
\fBNote:\fP
The strings are in \s-1ASCII\s+1 and converted to \s-1EBCDIC\s+1,
so beware of inserting
control codes.
.IP
There is also an alternate form of the \fBaString\fP function, \fBaHexString\fP,
which is used to enter non-printing data.
The argument to \fBaHexString\fP is a string of hexadecimal digits, two per
character.  A leading 0x or 0X is optional.
In 3270 mode, the hexadecimal data represent \s-1EBCDIC\s+1 characters, which
are entered into the current field.
In \s-1NVT\s+1 mode, the hexadecimal data represent \s-1ASCII\s+1 characters,
which are sent directly to the host.
.SH "PASSTHRU"
\fBlib3270\fP supports the Sun \fItelnet-passthru\fP
service provided by the \fIin.telnet-gw\fP server.
This allows outbound telnet connections through a firewall machine.
When a \fBp:\fP is prepended to a hostname, \fBlib3270\fP
acts much like the \fIitelnet\fP(1) command.
It contacts the machine named \fBinternet-gateway\fP at the port defined in
\fB/etc/services\fP as \fBtelnet-passthru\fP
(which defaults to 3514).
It then passes the requested hostname and port to the
\fBin.telnet-gw\fP server.
.SH "RESOURCES"
Certain \fBlib3270\fP
options can be configured via resources.
Resources are defined
by \fB\-xrm\fP options.
The definitions are similar to X11 resources, and use a similar syntax.
The resources available in \fBlib3270\fP are:
.LP
.TS
l l l l.
T{
.na
.nh
Resource
T}	T{
.na
.nh
Default
T}	T{
.na
.nh
Option
T}	T{
.na
.nh
Purpose
T}
_
T{
.na
.nh
blankFill
T}	T{
.na
.nh
False
T}	T{
.na
.nh
\-set blankFill
T}	T{
.na
.nh
Blank Fill mode
T}
T{
.na
.nh
charset
T}	T{
.na
.nh
bracket
T}	T{
.na
.nh
\-charset
T}	T{
.na
.nh
\s-1EBCDIC\s+1 character set
T}
T{
.na
.nh
charset.\fIfoo\fP
T}	T{
.na
.nh
\ 
T}	T{
.na
.nh
\ 
T}	T{
.na
.nh
Definition of character set \fIfoo\fP
T}
T{
.na
.nh
dsTrace
T}	T{
.na
.nh
False
T}	T{
.na
.nh
\-trace
T}	T{
.na
.nh
Data stream tracing
T}
T{
.na
.nh
eof
T}	T{
.na
.nh
^D
T}	T{
.na
.nh
\ 
T}	T{
.na
.nh
\s-1NVT\s+1-mode \s-1EOF\s+1 character
T}
T{
.na
.nh
erase
T}	T{
.na
.nh
^H
T}	T{
.na
.nh
\ 
T}	T{
.na
.nh
\s-1NVT\s+1-mode erase character
T}
T{
.na
.nh
extended
T}	T{
.na
.nh
True
T}	T{
.na
.nh
\ 
T}	T{
.na
.nh
Use 3270 extended data stream
T}
T{
.na
.nh
eventTrace
T}	T{
.na
.nh
False
T}	T{
.na
.nh
\-trace
T}	T{
.na
.nh
Event tracing
T}
T{
.na
.nh
ftCommand
T}	T{
.na
.nh
ind$file
T}	T{
.na
.nh
\ 
T}	T{
.na
.nh
Host file transfer command
T}
T{
.na
.nh
icrnl
T}	T{
.na
.nh
False
T}	T{
.na
.nh
\ 
T}	T{
.na
.nh
Map \s-1CR\s+1 to \s-1NL\s+1 on \s-1NVT\s+1-mode input
T}
T{
.na
.nh
inlcr
T}	T{
.na
.nh
False
T}	T{
.na
.nh
\ 
T}	T{
.na
.nh
Map \s-1NL\s+1 to \s-1CR\s+1 in \s-1NVT\s+1-mode input
T}
T{
.na
.nh
intr
T}	T{
.na
.nh
^C
T}	T{
.na
.nh
\ 
T}	T{
.na
.nh
\s-1NVT\s+1-mode interrupt character
T}
T{
.na
.nh
kill
T}	T{
.na
.nh
^U
T}	T{
.na
.nh
\ 
T}	T{
.na
.nh
\s-1NVT\s+1-mode kill character
T}
T{
.na
.nh
lineWrap
T}	T{
.na
.nh
False
T}	T{
.na
.nh
\-set lineWrap
T}	T{
.na
.nh
\s-1NVT\s+1 line wrap mode
T}
T{
.na
.nh
lnext
T}	T{
.na
.nh
^V
T}	T{
.na
.nh
\ 
T}	T{
.na
.nh
\s-1NVT\s+1-mode lnext character
T}
T{
.na
.nh
m3279
T}	T{
.na
.nh
(note 1)
T}	T{
.na
.nh
\-mono
T}	T{
.na
.nh
3279 (color) emulation
T}
T{
.na
.nh
monoCase
T}	T{
.na
.nh
False
T}	T{
.na
.nh
\-set monoCase
T}	T{
.na
.nh
Mono-case mode
T}
T{
.na
.nh
numericLock
T}	T{
.na
.nh
False
T}	T{
.na
.nh
\ 
T}	T{
.na
.nh
Lock keyboard for numeric field error
T}
T{
.na
.nh
oerrLock
T}	T{
.na
.nh
False
T}	T{
.na
.nh
\ 
T}	T{
.na
.nh
Lock keyboard for input error
T}
T{
.na
.nh
oversize
T}	T{
.na
.nh
\ 
T}	T{
.na
.nh
\-oversize
T}	T{
.na
.nh
Oversize screen dimensions
T}
T{
.na
.nh
port
T}	T{
.na
.nh
telnet
T}	T{
.na
.nh
\-port
T}	T{
.na
.nh
Non-default TCP port
T}
T{
.na
.nh
quit
T}	T{
.na
.nh
^\e
T}	T{
.na
.nh
\ 
T}	T{
.na
.nh
\s-1NVT\s+1-mode quit character
T}
T{
.na
.nh
rprnt
T}	T{
.na
.nh
^R
T}	T{
.na
.nh
\ 
T}	T{
.na
.nh
\s-1NVT\s+1-mode reprint character
T}
T{
.na
.nh
secure
T}	T{
.na
.nh
False
T}	T{
.na
.nh
\ 
T}	T{
.na
.nh
Disable "dangerous" options
T}
T{
.na
.nh
termName
T}	T{
.na
.nh
(note 2)
T}	T{
.na
.nh
\-tn
T}	T{
.na
.nh
\s-1TELNET\s+1 terminal type string
T}
T{
.na
.nh
traceDir
T}	T{
.na
.nh
/tmp
T}	T{
.na
.nh
\ 
T}	T{
.na
.nh
Directory for trace files
T}
T{
.na
.nh
traceFile
T}	T{
.na
.nh
(note 3)
T}	T{
.na
.nh
\-tracefile
T}	T{
.na
.nh
File for trace output
T}
T{
.na
.nh
werase
T}	T{
.na
.nh
^W
T}	T{
.na
.nh
\ 
T}	T{
.na
.nh
\s-1NVT\s+1-mode word-erase character
T}
.TE
.LP
.RS
\fINote 1\fP: \fBm3279\fP defaults to
\fBFalse\fP.  It can be forced to \fBTrue\fP with the \fB\-model\fP option.
.LP
\fINote 2\fP:
The default terminal type string is constructed from the model number, color
emulation, and extended data stream modes.
E.g., a model 2 with color emulation and the extended data stream option
would be sent as \fBIBM-3279-2-E\fP.
Note also that when \s-1TN3270E\s+1
mode is used, the terminal type is always sent as some type of 3278.
.LP
\fINote 3\fP: The default trace file is \fBx3trc.\fP\fIpid\fP
in the directory specified by the \fBtraceDir\fP resource.

.RE
.LP
If more than one \fB\-xrm\fP option is given for the same resource,
the last one on the command line is used.
.SH "SEE ALSO"
x3270(1), s3270(1), c3270(1), tcl3270(1), pr3287(1), telnet(1), tn3270(1)
.br
Data Stream Programmer's Reference, IBM GA23-0059
.br
Character Set Reference, IBM GA27-3831
.br
RFC 1576, TN3270 Current Practices
.br
RFC 1646, TN3270 Extensions for LUname and Printer Selection
.br
RFC 2355, TN3270 Enhancements
.SH "COPYRIGHTS"
.LP
Modifications Copyright 1993, 1994, 1995, 1996, 1997, 1999, 2000, 2001 by Paul Mattes.
.br
Original X11 Port Copyright 1990 by Jeff Sparkes.
.RS
Permission to use, copy, modify, and distribute this software and its
documentation for any purpose and without fee is hereby granted,
provided that the above copyright notice appear in all copies and that
both that copyright notice and this permission notice appear in
supporting documentation.
.RE
Copyright 1989 by Georgia Tech Research Corporation, Atlanta, GA 30332.
.RS
All Rights Reserved.  GTRC hereby grants public use of this software.
Derivative works based on this software must incorporate this copyright
notice.
.RE
5250 Emulation Code Copyright Minolta (Schweiz) AG, Beat Rubischon.
.SH "VERSION"
lib3270 3.2.19
